****************
chemistry_tools
****************

.. image:: https://travis-ci.org/domdfcoding/chemistry_tools.svg?branch=master
    :target: https://travis-ci.org/domdfcoding/chemistry_tools
    :alt: Build Status
.. image:: https://readthedocs.org/projects/chemistry_tools/badge/?version=latest
    :target: https://chemistry_tools.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status
.. image:: https://img.shields.io/pypi/v/chemistry_tools.svg
    :target: https://pypi.org/project/chemistry_tools/
    :alt: PyPI
.. image:: https://img.shields.io/pypi/pyversions/chemistry_tools.svg
    :target: https://pypi.org/project/chemistry_tools/
    :alt: PyPI - Python Version
.. image:: https://coveralls.io/repos/github/domdfcoding/chemistry_tools/badge.svg?branch=master
    :target: https://coveralls.io/github/domdfcoding/chemistry_tools?branch=master
    :alt: Coverage


Python tools for analysis of chemical compounds


Lookup adapted from PubChemPy
======================================
Copyright 2017 Matt Swain <m.swain@me.com>

https://github.com/mcs07/PubChemPy

Available under the MIT License


SpectrumSimilarity
======================================
Adapted from SpectrumSimilarity.R
Part of OrgMassSpecR

Copyright 2011-2017 Nathan Dodder <nathand@sccwrp.org>

https://cran.r-project.org/web/packages/OrgMassSpecR/index.html

Available under the BSD 2-Clause License

